Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Configuration struct {
//BindPort the port on which redsocks would listen to tunnel traffic
BindPort int64
//BindAddress the address on which redsocks would listen to tunnel traffic
BindAddress string
ProxyAddress string
//ProxyPort the proxy port
ProxyPort int64
//ProxyType the proxy type. Available options : as per redsocks support
ProxyType string
//ProxyUser the proxy user (if authentication applies)
ProxyUser string
//ProxyPassword the proxy password (if authentication applies)
ProxyPassword string
//TunnelPort the port through which traffic is tunneled
TunnelPort int64
//TunnelBindAddress the tunnel bind address
TunnelBindAddress string
}
Configuration redsocks configuration params
type Context ¶
type Context struct {
Command *exec.Cmd
Configfile *os.File
*Configuration
sync.Mutex
// contains filtered or unexported fields
}
Context A base structure representing a Redsocks execution context
func NewContext ¶
func NewContext(configuration *Configuration) (*Context, error)
NewContext New Creates and initialize a Redsocks context
Click to show internal directories.
Click to hide internal directories.